pymod
========================

Python sample module

---------------

使い方

- prepare
  
  - create git remote repo

- init

  - clone this repo
  - rm -rf .git
  - git init
  - git remote add origin

- edit

  - setup.py: name, description, url
  - readme.rst

- register to pypi

  - coming soon

- git

  - git add & commit & push
